# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 18:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SPLineChart',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name')),
                ('code', models.CharField(max_length=100, unique=True, verbose_name='Code')),
                ('type', models.IntegerField(choices=[(1, 'pie'), (2, 'spline')], verbose_name='Type')),
                ('data_url', models.URLField(help_text='Url from we will get data.', verbose_name='Data URL')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



#! -*- coding: utf-8 -*-
from django.template import Library
from django.urls import reverse

register = Library()

from django_charts import models

@register.inclusion_tag('django_charts/charts/js/spline.js.html')
def add_spline_chart_js(chart_code):
    chart = models.SPLineChart.objects.get(code=chart_code)

    data = {
        'code': chart_code,
        'title': chart.title,
        'x_axis_title' : chart.x_axis_title,
        'x_axis_format' : chart.x_axis_format,
        'x_axis_suffix' : chart.x_axis_suffix,
        'x_axis_preix' : chart.x_axis_preix,
        'x_axis_extra_options' : chart.x_axis_extra_options,
        'y_axis_title' : chart.y_axis_title,
        'y_axis_format' : chart.y_axis_format,
        'y_axis_suffix' : chart.y_axis_suffix,
        'y_axis_preix' : chart.y_axis_preix,
        'y_axis_extra_options' : chart.y_axis_extra_options,
        'y_data_format' : chart.y_data_format,
        'x_data_format' : chart.x_data_format,

        'data_url': reverse(chart.data_url_name),
    }

    return data

@register.inclusion_tag('django_charts/charts/html/spline.html')
def add_spline_chart_html(chart_code):
    data = {'code': chart_code}
    return data

@register.inclusion_tag('django_charts/charts/js/pie.js.html')
def add_pie_chart_js(chart_code):
    chart = models.PieChart.objects.get(code=chart_code)

    data = {
        'code': chart_code,
        'title': chart.title,
        # 'x_axis_title' : chart.x_axis_title,
        # 'x_axis_format' : chart.x_axis_format,
        # 'x_axis_suffix' : chart.x_axis_suffix,
        # 'x_axis_preix' : chart.x_axis_preix,
        # 'x_axis_extra_options' : chart.x_axis_extra_options,
        # 'y_axis_title' : chart.y_axis_title,
        # 'y_axis_format' : chart.y_axis_format,
        # 'y_axis_suffix' : chart.y_axis_suffix,
        # 'y_axis_preix' : chart.y_axis_preix,
        # 'y_axis_extra_options' : chart.y_axis_extra_options,
        # 'y_data_format' : chart.y_data_format,
        # 'x_data_format' : chart.x_data_format,

        'data_url': reverse(chart.data_url_name),
    }

    return data

@register.inclusion_tag('django_charts/charts/html/pie.html')
def add_pie_chart_html(chart_code):
    data = {'code': chart_code}
    return data


# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 20:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0005_auto_20180707_1612'),
    ]

    operations = [
        migrations.AlterField(
            model_name='splinechart',
            name='x_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='X data format'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='y_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='Y data format'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 19:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='splinechart',
            options={'verbose_name': 'SPLine Chart', 'verbose_name_plural': 'SPLine Charts'},
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='data_url',
            field=models.CharField(help_text='Django url name for getting the data from.', max_length=255, verbose_name='Data URL'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='title',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Title'),
        ),
    ]



from django.contrib import admin
from django_charts import models



class AdminSPLineCharts(admin.ModelAdmin):
    list_display = ('title', 'desc')


class AdminPieCharts(admin.ModelAdmin):
    list_display = ('title', 'desc')


admin.site.register(models.SPLineChart, AdminSPLineCharts)
admin.site.register(models.PieChart, AdminPieCharts)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 19:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0003_auto_20180707_1501'),
    ]

    operations = [
        migrations.AddField(
            model_name='splinechart',
            name='desc',
            field=models.TextField(blank=True, help_text='Optional chart description', null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='data_url_name',
            field=models.CharField(help_text='Django url name for getting the data from.', max_length=255, verbose_name='Data URL Name'),
        ),
    ]



#! -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.utils.translation import ugettext_lazy as _


class Chart(models.Model):

    title = models.CharField(_('Title'), max_length=100, null=True, blank=True)

    code = models.CharField(
        _('Code'), max_length=100, null=False, blank=False, unique=True
    )

    PIE = 1
    SPLINE = 2

    TYPE_OPTIONS = (
        (PIE, "pie"),
        (SPLINE, "spline")
    )

    type = models.IntegerField(
        _('Type'), null=False, blank=False, choices=TYPE_OPTIONS
    )

    data_url_name = models.CharField(
        _('Data URL Name'), max_length=255, blank=False, null=False,
        help_text=_("Django url name for getting the data from.")
    )

    desc = models.TextField(
        _('Description'), null=True, blank=True,
        help_text=_("Optional chart description")
    )

    class Meta:
        abstract = True

    def __unicode__(self):
        return self.title


class SPLineChart(Chart):

    """
    Data format expected to be returned from data_url:

        [
			{x: new Date(2002, 0), y: 2506000},
			{x: new Date(2003, 0), y: 2798000},
			{x: new Date(2004, 0), y: 3386000},
			{x: new Date(2005, 0), y: 6944000},
			{x: new Date(2006, 0), y: 6026000},
			{x: new Date(2007, 0), y: 2394000},
			{x: new Date(2008, 0), y: 1872000},
			{x: new Date(2009, 0), y: 2140000},
			{x: new Date(2010, 0), y: 7289000},
			{x: new Date(2011, 0), y: 4830000},
			{x: new Date(2012, 0), y: 2009000},
			{x: new Date(2013, 0), y: 2840000},
			{x: new Date(2014, 0), y: 2396000},
			{x: new Date(2015, 0), y: 1613000},
			{x: new Date(2016, 0), y: 2821000},
			{x: new Date(2017, 0), y: 2000000}
		]
    """

    x_axis_title = models.CharField(_("X axis title"), max_length=32, null=True, blank=True)
    x_axis_format = models.CharField(_("X axis format"), max_length=32, null=True, blank=True)
    x_axis_suffix = models.CharField(_("X axis suffix"), max_length=32, null=True, blank=True)
    x_axis_preix = models.CharField(_("X axis preix"), max_length=32, null=True, blank=True)
    x_axis_extra_options = models.CharField(_("X axis extra_options"), max_length=32, null=True, blank=True)

    y_axis_title = models.CharField(_("Y axis title"), max_length=32, null=True, blank=True)
    y_axis_format = models.CharField(_("Y axis format"), max_length=32, null=True, blank=True)
    y_axis_suffix = models.CharField(_("Y axis suffix"), max_length=32, null=True, blank=True)
    y_axis_preix = models.CharField(_("Y axis preix"), max_length=32, null=True, blank=True)
    y_axis_extra_options = models.CharField(_("Y axis extra_options"), max_length=32, null=True, blank=True)

    y_data_format = models.TextField(_("Y axis data format"), max_length=16, null=True, blank=True)
    x_data_format = models.TextField(_("X axis data format"), max_length=16, null=True, blank=True)

    class Meta:
        verbose_name = "SPLine Chart"
        verbose_name_plural = "SPLine Charts"

class PieChart(Chart):

    class Meta:
        verbose_name = "Pie Chart"
        verbose_name_plural = "Pie Charts"



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 20:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0004_auto_20180707_1505'),
    ]

    operations = [
        migrations.AddField(
            model_name='splinechart',
            name='x_axis_extra_options',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='X axis extra_options'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='x_axis_format',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='X axis format'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='x_axis_preix',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='X axis preix'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='x_axis_suffix',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='X axis suffix'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='x_axis_title',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='X axis title'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='x_data_format',
            field=models.CharField(blank=True, max_length=16, null=True, verbose_name='X data format'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='y_axis_extra_options',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='Y axis extra_options'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='y_axis_format',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='Y axis format'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='y_axis_preix',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='Y axis preix'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='y_axis_suffix',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='Y axis suffix'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='y_axis_title',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='Y axis title'),
        ),
        migrations.AddField(
            model_name='splinechart',
            name='y_data_format',
            field=models.CharField(blank=True, max_length=16, null=True, verbose_name='Y data format'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-08 21:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0006_auto_20180707_1631'),
    ]

    operations = [
        migrations.CreateModel(
            name='PieChart',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Title')),
                ('code', models.CharField(max_length=100, unique=True, verbose_name='Code')),
                ('type', models.IntegerField(choices=[(1, 'pie'), (2, 'spline')], verbose_name='Type')),
                ('data_url_name', models.CharField(help_text='Django url name for getting the data from.', max_length=255, verbose_name='Data URL Name')),
                ('desc', models.TextField(blank=True, help_text='Optional chart description', null=True, verbose_name='Description')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'SPLine Chart',
                'verbose_name_plural': 'SPLine Charts',
            },
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='x_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='X axis data format'),
        ),
        migrations.AlterField(
            model_name='splinechart',
            name='y_data_format',
            field=models.TextField(blank=True, max_length=16, null=True, verbose_name='Y axis data format'),
        ),
    ]



import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="CanvasJS Django Charts",
    version="0.1a-r1",
    author="Raydel Miranda",
    author_email="raydel.miranda.gomez@gmail.com",
    description="App for charts generation for django apps.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://bitbucket.org/elasbit/fc-cloudtrails-sdk-py/src/develop/",
    packages=[
        'django_charts',
        'django_charts.migrations',
        'django_charts.templatetags'
    ],
    package_dir={
        'django_charts': 'django_charts'
    },
    package_data={
        'django_charts': ['templates/*']
    },
    classifiers=(
        "Programming Language :: Python :: 2",
        "Operating System :: OS Independent",
    ),
)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-07-07 19:01
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_charts', '0002_auto_20180707_1500'),
    ]

    operations = [
        migrations.RenameField(
            model_name='splinechart',
            old_name='data_url',
            new_name='data_url_name',
        ),
    ]
